.*: Assembler messages:
.*:3: Error: illegal operands \(vd must be even\) `smt.vmadot v1,v3,v4'
.*:4: Error: illegal operands \(vd must be even\) `smt.vmadotu v1,v3,v4'
.*:5: Error: illegal operands \(vd must be even\) `smt.vmadotsu v1,v3,v4'
.*:6: Error: illegal operands \(vd must be even\) `smt.vmadotus v1,v3,v4'
.*:7: Error: illegal operands \(vd must be even\) `smt.vmadot1u v1,v4,v5'
.*:8: Error: illegal operands \(vd must be even\) `smt.vmadot1 v1,v4,v5'
.*:9: Error: illegal operands \(vd must be even\) `smt.vmadot1su v1,v4,v5'
.*:10: Error: illegal operands \(vd must be even\) `smt.vmadot1us v1,v4,v5'
.*:11: Error: illegal operands \(vd must be even\) `smt.vmadot2u v1,v4,v5'
.*:12: Error: illegal operands \(vd must be even\) `smt.vmadot2 v1,v4,v5'
.*:13: Error: illegal operands \(vd must be even\) `smt.vmadot2su v1,v4,v5'
.*:14: Error: illegal operands \(vd must be even\) `smt.vmadot2us v1,v4,v5'
.*:15: Error: illegal operands \(vd must be even\) `smt.vmadot3u v1,v4,v5'
.*:16: Error: illegal operands \(vd must be even\) `smt.vmadot3 v1,v4,v5'
.*:17: Error: illegal operands \(vd must be even\) `smt.vmadot3su v1,v4,v5'
.*:18: Error: illegal operands \(vd must be even\) `smt.vmadot3us v1,v4,v5'
.*:20: Error: illegal operands \(vs1 must be even\) `smt.vmadot1u v2,v3,v5'
.*:21: Error: illegal operands \(vs1 must be even\) `smt.vmadot1 v2,v3,v5'
.*:22: Error: illegal operands \(vs1 must be even\) `smt.vmadot1su v2,v3,v5'
.*:23: Error: illegal operands \(vs1 must be even\) `smt.vmadot1us v2,v3,v5'
.*:24: Error: illegal operands \(vs1 must be even\) `smt.vmadot2u v2,v3,v5'
.*:25: Error: illegal operands \(vs1 must be even\) `smt.vmadot2 v2,v3,v5'
.*:26: Error: illegal operands \(vs1 must be even\) `smt.vmadot2su v2,v3,v5'
.*:27: Error: illegal operands \(vs1 must be even\) `smt.vmadot2us v2,v3,v5'
.*:28: Error: illegal operands \(vs1 must be even\) `smt.vmadot3u v2,v3,v5'
.*:29: Error: illegal operands \(vs1 must be even\) `smt.vmadot3 v2,v3,v5'
.*:30: Error: illegal operands \(vs1 must be even\) `smt.vmadot3su v2,v3,v5'
.*:31: Error: illegal operands \(vs1 must be even\) `smt.vmadot3us v2,v3,v5'
.*:33: Error: illegal operands \(invalid data type\) `smt.vmadot v2,v3,v4,i1'
.*:34: Error: illegal operands \(invalid data type\) `smt.vmadot v2,v3,v4,i2'
.*:35: Error: illegal operands \(invalid data type\) `smt.vmadot v2,v3,v4,i3'
.*:36: Error: illegal operands \(invalid data type\) `smt.vmadot v2,v3,v4,i4'
.*:37: Error: illegal operands \(invalid data type\) `smt.vmadot v2,v3,v4,i5'
.*:38: Error: illegal operands \(invalid data type\) `smt.vmadot v2,v3,v4,i7'
.*:39: Error: illegal operands \(invalid data type\) `smt.vmadot v2,v3,v4,i16'
.*:40: Error: illegal operands \(invalid data type\) `smt.vmadot v2,v3,v4,i32'
.*:41: Error: illegal operands \(invalid data type\) `smt.vmadot v2,v3,v4,i64'
.*:42: Error: illegal operands \(invalid data type\) `smt.vmadot1u v2,v4,v5,i2'
.*:43: Error: illegal operands \(invalid data type\) `smt.vmadot2u v2,v4,v5,i4'
.*:44: Error: illegal operands \(invalid data type\) `smt.vmadot3u v2,v4,v5,i16'
.*:2: Error: unrecognized opcode `smt.vmadot v2,v3,v4', extension `xsmtvdot' or `xsmtvdotii' required
.*:3: Error: unrecognized opcode `smt.vmadotu v2,v3,v4', extension `xsmtvdot' or `xsmtvdotii' required
.*:4: Error: unrecognized opcode `smt.vmadotsu v2,v3,v4', extension `xsmtvdot' or `xsmtvdotii' required
.*:5: Error: unrecognized opcode `smt.vmadotus v2,v3,v4', extension `xsmtvdot' or `xsmtvdotii' required
.*:6: Error: unrecognized opcode `smt.vmadot1u v2,v4,v5', extension `xsmtvdot' or `xsmtvdotii' required
.*:7: Error: unrecognized opcode `smt.vmadot1 v2,v4,v5', extension `xsmtvdot' or `xsmtvdotii' required
.*:8: Error: unrecognized opcode `smt.vmadot1su v2,v4,v5', extension `xsmtvdot' or `xsmtvdotii' required
.*:9: Error: unrecognized opcode `smt.vmadot1us v2,v4,v5', extension `xsmtvdot' or `xsmtvdotii' required
.*:10: Error: unrecognized opcode `smt.vmadot2u v2,v4,v5', extension `xsmtvdot' or `xsmtvdotii' required
.*:11: Error: unrecognized opcode `smt.vmadot2 v2,v4,v5', extension `xsmtvdot' or `xsmtvdotii' required
.*:12: Error: unrecognized opcode `smt.vmadot2su v2,v4,v5', extension `xsmtvdot' or `xsmtvdotii' required
.*:13: Error: unrecognized opcode `smt.vmadot2us v2,v4,v5', extension `xsmtvdot' or `xsmtvdotii' required
.*:14: Error: unrecognized opcode `smt.vmadot3u v2,v4,v5', extension `xsmtvdot' or `xsmtvdotii' required
.*:15: Error: unrecognized opcode `smt.vmadot3 v2,v4,v5', extension `xsmtvdot' or `xsmtvdotii' required
.*:16: Error: unrecognized opcode `smt.vmadot3su v2,v4,v5', extension `xsmtvdot' or `xsmtvdotii' required
.*:17: Error: unrecognized opcode `smt.vmadot3us v2,v4,v5', extension `xsmtvdot' or `xsmtvdotii' required
.*:18: Error: unrecognized opcode `smt.vmadot v2,v3,v4,i8', extension `xsmtvdot' or `xsmtvdotii' required
.*:19: Error: unrecognized opcode `smt.vmadotu v2,v3,v4,i8', extension `xsmtvdot' or `xsmtvdotii' required
.*:20: Error: unrecognized opcode `smt.vmadotsu v2,v3,v4,i8', extension `xsmtvdot' or `xsmtvdotii' required
.*:21: Error: unrecognized opcode `smt.vmadotus v2,v3,v4,i8', extension `xsmtvdot' or `xsmtvdotii' required
.*:22: Error: unrecognized opcode `smt.vmadot1u v2,v4,v5,i8', extension `xsmtvdot' or `xsmtvdotii' required
.*:23: Error: unrecognized opcode `smt.vmadot1 v2,v4,v5,i8', extension `xsmtvdot' or `xsmtvdotii' required
.*:24: Error: unrecognized opcode `smt.vmadot1su v2,v4,v5,i8', extension `xsmtvdot' or `xsmtvdotii' required
.*:25: Error: unrecognized opcode `smt.vmadot1us v2,v4,v5,i8', extension `xsmtvdot' or `xsmtvdotii' required
.*:26: Error: unrecognized opcode `smt.vmadot2u v2,v4,v5,i8', extension `xsmtvdot' or `xsmtvdotii' required
.*:27: Error: unrecognized opcode `smt.vmadot2 v2,v4,v5,i8', extension `xsmtvdot' or `xsmtvdotii' required
.*:28: Error: unrecognized opcode `smt.vmadot2su v2,v4,v5,i8', extension `xsmtvdot' or `xsmtvdotii' required
.*:29: Error: unrecognized opcode `smt.vmadot2us v2,v4,v5,i8', extension `xsmtvdot' or `xsmtvdotii' required
.*:30: Error: unrecognized opcode `smt.vmadot3u v2,v4,v5,i8', extension `xsmtvdot' or `xsmtvdotii' required
.*:31: Error: unrecognized opcode `smt.vmadot3 v2,v4,v5,i8', extension `xsmtvdot' or `xsmtvdotii' required
.*:32: Error: unrecognized opcode `smt.vmadot3su v2,v4,v5,i8', extension `xsmtvdot' or `xsmtvdotii' required
.*:33: Error: unrecognized opcode `smt.vmadot3us v2,v4,v5,i8', extension `xsmtvdot' or `xsmtvdotii' required
